import { type ValidationArgs } from "@vuelidate/core";
import { type Component } from "vue";
export type FormBuilderModel = Record<string, boolean | string | number | Date | string[] | null>;
export interface FormElementItem<Model> {
    key: string;
    props: () => any;
    formFieldProps?: () => any;
    validation?: (model: Model) => ValidationArgs;
    formFieldComponent?: Component;
    component: Component;
    isReadOnly?: (model: Model) => boolean;
    isHidden?: (model: Model) => boolean;
    mandatory?: boolean;
}
export interface FormElementSection<Model> {
    title: string;
    description?: string;
    elements: FormElementItem<Model>[];
    component?: Component;
}
export interface FormElement<Model> {
    sets: FormElementSection<Model>[];
}
export type FormElementError = {
    [key: string]: {
        [key: string]: string;
    };
};
export interface FormOptions<Model> {
    validation?: (model: Model) => ValidationArgs;
    isReadOnly?: (model: Model) => boolean;
    isHidden?: (model: Model) => boolean;
    mandatory?: boolean;
}
